emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

master 527bab0: Handle test environment variables


From: Michael Albinus
Subject: master 527bab0: Handle test environment variables
Date: Thu, 1 Jul 2021 07:43:51 -0400 (EDT)

branch: master
commit 527bab054f285cde9d7f792c932c40ddcce74590
Author: Michael Albinus <michael.albinus@gmx.de>
Commit: Michael Albinus <michael.albinus@gmx.de>

    Handle test environment variables
    
    * lisp/emacs-lisp/ert.el (ert-summarize-tests-batch-and-exit):
    Check also for EMACS_EMBA_CI.
    
    * test/README (SELECTOR): Mention EMACS_TEST_VERBOSE.
    
    * test/infra/gitlab-ci.yml (variables): Set EMACS_TEST_VERBOSE.
---
 lisp/emacs-lisp/ert.el   | 6 +++---
 test/README              | 5 +++++
 test/infra/gitlab-ci.yml | 1 +
 3 files changed, 9 insertions(+), 3 deletions(-)

diff --git a/test/README b/test/README
index 0c8d5a4..97611cf 100644
--- a/test/README
+++ b/test/README
@@ -105,6 +105,11 @@ debugging.  To do that, use
 
     make TEST_INTERACTIVE=yes ...
 
+By default, ERT test failure summaries are quite brief in batch
+mode--only the names of the failed tests are listed.  If the
+$EMACS_TEST_VERBOSE environment variable is set, the failure summaries
+will also include the data from the failing test.
+
 Some of the tests require a remote temporary directory
 (autorevert-tests.el, filenotify-tests.el, shadowfile-tests.el and
 tramp-tests.el).  Per default, a mock-up connection method is used
diff --git a/test/infra/gitlab-ci.yml b/test/infra/gitlab-ci.yml
index fa10fa6..6876a8b 100644
--- a/test/infra/gitlab-ci.yml
+++ b/test/infra/gitlab-ci.yml
@@ -44,6 +44,7 @@ workflow:
 variables:
   GIT_STRATEGY: fetch
   EMACS_EMBA_CI: 1
+  EMACS_TEST_VERBOSE: 1
   # # Use TLS 
https://docs.gitlab.com/ee/ci/docker/using_docker_build.html#tls-enabled
   # DOCKER_HOST: tcp://docker:2376
   # DOCKER_TLS_CERTDIR: "/certs"



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/emacs-lisp/ert.el b/lisp/emacs-lisp/ert.el
index 50b4509..92acfe7 100644
--- a/lisp/emacs-lisp/ert.el
+++ b/lisp/emacs-lisp/ert.el
@@ -1552,7 +1552,7 @@ Ran \\([0-9]+\\) tests, \\([0-9]+\\) results as expected\
     (when badtests
       (message "%d files did not finish:" (length badtests))
       (mapc (lambda (l) (message "  %s" l)) badtests)
-      (if (getenv "EMACS_HYDRA_CI")
+      (if (or (getenv "EMACS_HYDRA_CI") (getenv "EMACS_EMBA_CI"))
           (with-temp-buffer
             (dolist (f badtests)
               (erase-buffer)
@@ -1568,8 +1568,8 @@ Ran \\([0-9]+\\) tests, \\([0-9]+\\) results as expected\
       (setq tests (sort tests (lambda (x y) (> (car x) (car y)))))
       (when (< high (length tests)) (setcdr (nthcdr (1- high) tests) nil))
       (message "%s" (mapconcat #'cdr tests "\n")))
-    ;; More details on hydra, where the logs are harder to get to.
-    (when (and (getenv "EMACS_HYDRA_CI")
+    ;; More details on hydra and emba, where the logs are harder to get to.
+    (when (and (or (getenv "EMACS_HYDRA_CI") (getenv "EMACS_EMBA_CI"))
                (not (zerop (+ nunexpected nskipped))))
       (message "\nDETAILS")
       (message "-------")